@@ -22,7 +22,10 @@
 #include "timescaleconfigdialog.h"
 #include "prefs.h"
 
+#include <KCalUtils/Stringify>
+
 #include <KLocalizedString>
+
 #include <QIcon>
 #include <QDialogButtonBox>
 #include <QPushButton>
@@ -51,32 +54,12 @@ enum {
 
 typedef QPair<QString, QByteArray> TimeZoneNamePair;
 
-//TODO: move to KCalCore::Stringify
-static QString tzUTCOffsetStr(const QTimeZone &tz)
-{
-    auto currentOffset = tz.offsetFromUtc(QDateTime::currentDateTimeUtc());
-    int utcOffsetHrs = currentOffset / 3600;  // in hours
-    int utcOffsetMins = (currentOffset % 3600) / 60;    // in minutes
-    QString utcStr;
-    if (utcOffsetMins > 0) {
-        utcStr = utcOffsetHrs >= 0
-                 ? QStringLiteral("+%1:%2").arg(utcOffsetHrs).arg(utcOffsetMins)
-                 : QStringLiteral("%1:%2").arg(utcOffsetHrs).arg(utcOffsetMins);
-    } else {
-        utcStr = utcOffsetHrs >= 0
-                 ? QStringLiteral("+%1").arg(utcOffsetHrs)
-                 : QStringLiteral("%1").arg(utcOffsetHrs);
-    }
-    return utcStr;
-}
-
-//TODO: move to KCalCore::Stringify
 static QString tzWithUTC(const QByteArray &zoneId)
 {
     auto tz = QTimeZone(zoneId);
     return
-        QStringLiteral("%1 (UTC%2)").
-        arg(i18n(zoneId.constData()), tzUTCOffsetStr(tz));
+        QStringLiteral("%1 (%2)").
+        arg(i18n(zoneId.constData()), KCalUtils::Stringify::tzUTCOffsetStr(tz));
 }
 
 TimeScaleConfigDialog::TimeScaleConfigDialog(const PrefsPtr &preferences, QWidget *parent)
@@ -133,11 +116,11 @@ TimeScaleConfigDialog::TimeScaleConfigDialog(const PrefsPtr &preferences, QWidge
     connect(downButton, &QPushButton::clicked, this, &TimeScaleConfigDialog::down);
 
     connect(okButton, &QPushButton::clicked, this, &TimeScaleConfigDialog::okClicked);
-    connect(buttonBox->button(
-                QDialogButtonBox::Cancel), &QPushButton::clicked, this,
-            &TimeScaleConfigDialog::reject);
-    connect(listWidget, &QListWidget::currentItemChanged, this,
-            &TimeScaleConfigDialog::slotUpdateButton);
+    connect(buttonBox->button(QDialogButtonBox::Cancel), &QPushButton::clicked,
+            this, &TimeScaleConfigDialog::reject);
+    connect(listWidget, &QListWidget::currentItemChanged,
+            this, &TimeScaleConfigDialog::slotUpdateButton);
+
     for (const TimeZoneNamePair &item : qAsConst(selList)) {
         QListWidgetItem *widgetItem = new QListWidgetItem(item.first);
         widgetItem->setData(TimeZoneNameRole, item.second);
@@ -156,8 +139,8 @@ void TimeScaleConfigDialog::slotUpdateButton()
     removeButton->setEnabled(listWidget->currentItem());
     const bool numberElementMoreThanOneElement = (listWidget->count() > 1);
     upButton->setEnabled(numberElementMoreThanOneElement && (listWidget->currentRow() >= 1));
-    downButton->setEnabled(numberElementMoreThanOneElement
-                           && (listWidget->currentRow() < listWidget->count() - 1));
+    downButton->setEnabled(numberElementMoreThanOneElement &&
+                           (listWidget->currentRow() < listWidget->count() - 1));
 }
 
 void TimeScaleConfigDialog::okClicked()
@@ -173,8 +156,8 @@ void TimeScaleConfigDialog::add()
     if (zoneCombo->currentIndex() >= 0) {
         const int numberItem(listWidget->count());
         for (int i = 0; i < numberItem; ++i) {
-            if (listWidget->item(i)->data(TimeZoneNameRole).toString()
-                == zoneCombo->itemData(zoneCombo->currentIndex(), TimeZoneNameRole).toString()) {
+            if (listWidget->item(i)->data(TimeZoneNameRole).toString() ==
+                zoneCombo->itemData(zoneCombo->currentIndex(), TimeZoneNameRole).toString()) {
                 return;
             }
         }
